# Changelog

## [0.1.1] - 2026-02-10

### Fixed

- `focus_window` がバックグラウンドプロセス（MCPサーバー）から呼び出された際に `SetForegroundWindow` が失敗する問題を修正
  - AttachThreadInput + Alt キーシミュレーションによるフォアグラウンドロック回避を実装

## [0.1.0] - 2025-06-07

初回リリース。

### Added

- ウィンドウ一覧取得（タイトルフィルタ対応）
- ディスプレイ一覧取得（マルチディスプレイ対応）
- スクリーンキャプチャ（フルスクリーン / 指定領域）
- 低画質プレビュー用 base64 画像生成
- ウィンドウ操作（フォーカス、最大化、リサイズ、移動）
- MCP サーバーとして FastMCP ベースで動作
